@@ -41,6 +41,7 @@ SAVETITLE = "Select Datalog Directory"
 READTITLE = "Select Datalog File"
 WAITNMEADATA = "Waiting for data..."
 WAITUBXDATA = "Waiting for data..."
+ENDOFFILE = "End of file reached"
 STOPDATA = "Serial reader process stopped"
 NOTCONN = "Not connected"
 UBXPOLL = "Polling current UBX configuration..."
@@ -95,12 +96,12 @@ DLGABOUT = "PyGPSClient"
 DLGHOWTO = "How To Use PyGPSCLient"
 DLGRESET = "Confirm Reset"
 DLGSAVE = "Confirm Save"
-DLGRESETCONFIRM = "Are you sure you want to reset the\ncurrent configuration to the\nfactory default in battery-backed RAM?"
-DLGSAVECONFIRM = "Are you sure you want to save\nthe current configuration to\nbattery-backed RAM?"
+DLGRESETCONFIRM = "Are you sure you want to reset the\ncurrent configuration to the\nfactory default?"
+DLGSAVECONFIRM = "Are you sure you want to save\nthe current configuration?"
 
 # UBX Preset Command Descriptions
 PSTRESET = 'CFG-CFG - RESTORE FACTORY DEFAULTS'
-PSTSAVE = 'CFG-CFG - Save current configuration to RAM'
+PSTSAVE = 'CFG-CFG - Save current configuration'
 PSTMINNMEAON = 'CFG-MSG - Turn ON minimum NMEA msgs'
 PSTALLNMEAON = 'CFG-MSG - Turn ON all NMEA msgs'
 PSTALLNMEAOFF = 'CFG-MSG - Turn OFF all NMEA msgs'
